pub struct Metrics {Show 27 fields
pub atq_enq: u64,
pub atq_reenq: u64,
pub dsq_change: u64,
pub same_dsq: u64,
pub keep: u64,
pub enq_cpu: u64,
pub enq_llc: u64,
pub enq_intr: u64,
pub enq_mig: u64,
pub select_pick2: u64,
pub dispatch_pick2: u64,
pub llc_migrations: u64,
pub node_migrations: u64,
pub direct: u64,
pub idle: u64,
pub wake_prev: u64,
pub wake_llc: u64,
pub wake_mig: u64,
pub fork_balance: u64,
pub exec_balance: u64,
pub fork_same_llc: u64,
pub exec_same_llc: u64,
pub thermal_kick: u64,
pub thermal_avoid: u64,
pub eas_little_select: u64,
pub eas_big_select: u64,
pub eas_fallback: u64,
}Fields
atq_enq: u64Number of times a task was enqueued to a ATQ
atq_reenq: u64Number of times a task was re-enqueued to a ATQ
dsq_change: u64Number of times tasks have switched DSQs
same_dsq: u64Number of times tasks have stayed on the same DSQ
keep: u64Number of times a task kept running
enq_cpu: u64Number of times a task was enqueued to CPUC DSQ
enq_llc: u64Number of times a task was enqueued to LLC DSQ
enq_intr: u64Number of times a task was enqueued to interactive DSQ
enq_mig: u64Number of times a task was enqueued to migration DSQ
select_pick2: u64Number of times a select_cpu pick 2 load balancing occurred
dispatch_pick2: u64Number of times a dispatch pick 2 load balancing occurred
llc_migrations: u64Number of times a task migrated LLCs
node_migrations: u64Number of times a task migrated NUMA nodes
direct: u64Number of times tasks have directly been dispatched to local per CPU DSQs
idle: u64Number of times tasks have dispatched to an idle local per CPU DSQs
wake_prev: u64Number of times tasks have been woken to the previous CPU
wake_llc: u64Number of times tasks have been woken to the previous llc
wake_mig: u64Number of times tasks have been woken and migrated llc
fork_balance: u64Number of times fork balancing migrated to different LLC
exec_balance: u64Number of times exec balancing migrated to different LLC
fork_same_llc: u64Number of times fork stayed on same LLC
exec_same_llc: u64Number of times exec stayed on same LLC
thermal_kick: u64Number of CPU kicks due to thermal pressure
thermal_avoid: u64Number of times throttled CPUs were avoided
eas_little_select: u64Number of times EAS placed task on little core
eas_big_select: u64Number of times EAS placed task on big core
eas_fallback: u64Number of times EAS fell back to non-preferred core type
Implementations